# References and relevant issues
<!-- What relevant resources were used in the creation of this PR?
If this PR addresses an existing issue on the repo,
please link to that issue here as "Closes #(issue-number)"
If this PR depends on another PR/issue (even in another repo),
please link to it with "Depends on #PR-number" or "Depends on org/repo#PR-number"
-->

# Description
<!-- What does this pull request (PR) do? Is it a new feature, a bug fix,
an improvement, or something else? Why is it necessary? If relevant, please add
a screenshot or a screen capture: "An image is worth a thousand words!" -->

<!-- AI Policy
The [napari AI use policy and guidelines](https://napari.org/dev/developers/contributing/ai.html) should be read and followed when using AI tools to assist with development.

TLDR: We are humans who enjoy working with other humans. You may use whatever tools you like, but you are ultimately responsible for the changes you submit. Don’t submit changes you haven’t carefully read through yourself, and let us have a conversation with you, not a chatbot.
-->

<!-- Final Checklist
- My PR is the minimum possible work for the desired functionality
- I have commented my code, particularly in hard-to-understand areas
- I have made corresponding changes to docstrings and documentation
  (open a PR on the docs repository (https://github.com/napari/docs) if relevant!)
- I have added tests that prove my fix is effective or that my feature works
- If an API has been modified, I have added a `.. versionadded::` or `.. versionchanged::`
  directive to the appropriate docstring (For more information see
  [the Sphinx documentation](https://www.sphinx-doc.org/en/master/usage/restructuredtext/directives.html#describing-changes-between-versions)).
-->
